summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEric Schulte <eric.schulte@gmx.com>2012-12-11 16:58:16 -0700
committerEric Schulte <eric.schulte@gmx.com>2012-12-12 10:48:56 -0700
commitff0081847c81f5a2f5526da0446d34236b0424ac (patch)
tree8de37dc6d4c30cc049b04ef053a1f8df8c477f4b
parent0694965865fd6c14f7c787153a33538584fbe0f5 (diff)
downloadorg-mode-ff0081847c81f5a2f5526da0446d34236b0424ac.tar.gz
requiring ob now pulls in all of Babel
-rw-r--r--lisp/ob-C.el1
-rw-r--r--lisp/ob-R.el3
-rw-r--r--lisp/ob-awk.el1
-rw-r--r--lisp/ob-calc.el1
-rw-r--r--lisp/ob-comint.el2
-rw-r--r--lisp/ob-core.el6
-rw-r--r--lisp/ob-dot.el1
-rw-r--r--lisp/ob-emacs-lisp.el1
-rw-r--r--lisp/ob-exp.el2
-rw-r--r--lisp/ob-fortran.el1
-rw-r--r--lisp/ob-gnuplot.el2
-rw-r--r--lisp/ob-haskell.el1
-rw-r--r--lisp/ob-io.el3
-rw-r--r--lisp/ob-java.el1
-rw-r--r--lisp/ob-js.el3
-rw-r--r--lisp/ob-keys.el2
-rw-r--r--lisp/ob-lilypond.el3
-rw-r--r--lisp/ob-lob.el2
-rw-r--r--lisp/ob-mscgen.el1
-rw-r--r--lisp/ob-ocaml.el1
-rw-r--r--lisp/ob-octave.el3
-rw-r--r--lisp/ob-perl.el1
-rw-r--r--lisp/ob-picolisp.el2
-rw-r--r--lisp/ob-plantuml.el1
-rw-r--r--lisp/ob-python.el3
-rw-r--r--lisp/ob-ref.el2
-rw-r--r--lisp/ob-ruby.el3
-rw-r--r--lisp/ob-sass.el1
-rw-r--r--lisp/ob-scala.el3
-rw-r--r--lisp/ob-scheme.el3
-rw-r--r--lisp/ob-screen.el1
-rw-r--r--lisp/ob-sh.el3
-rw-r--r--lisp/ob-sqlite.el2
-rw-r--r--lisp/ob-table.el2
-rw-r--r--lisp/ob-tangle.el1
-rw-r--r--lisp/ob.el41
-rw-r--r--lisp/org.el6
37 files changed, 50 insertions, 66 deletions
diff --git a/lisp/ob-C.el b/lisp/ob-C.el
index 55e4b40..195dd9e 100644
--- a/lisp/ob-C.el
+++ b/lisp/ob-C.el
@@ -31,7 +31,6 @@
;;; Code:
(require 'ob)
-(require 'ob-eval)
(require 'cc-mode)
(declare-function org-entry-get "org"
diff --git a/lisp/ob-R.el b/lisp/ob-R.el
index 5711f38..eb97bd2 100644
--- a/lisp/ob-R.el
+++ b/lisp/ob-R.el
@@ -28,9 +28,6 @@
;;; Code:
(require 'ob)
-(require 'ob-ref)
-(require 'ob-comint)
-(require 'ob-eval)
(eval-when-compile (require 'cl))
(declare-function orgtbl-to-tsv "org-table" (table params))
diff --git a/lisp/ob-awk.el b/lisp/ob-awk.el
index 6ce67f4..444728a 100644
--- a/lisp/ob-awk.el
+++ b/lisp/ob-awk.el
@@ -32,7 +32,6 @@
;;; Code:
(require 'ob)
-(require 'ob-eval)
(require 'org-compat)
(eval-when-compile (require 'cl))
diff --git a/lisp/ob-calc.el b/lisp/ob-calc.el
index c79d0b5..4eaf51a 100644
--- a/lisp/ob-calc.el
+++ b/lisp/ob-calc.el
@@ -31,7 +31,6 @@
(unless (featurep 'xemacs)
(require 'calc-trail)
(require 'calc-store))
-(eval-when-compile (require 'ob-comint))
(declare-function calc-store-into "calc-store" (&optional var))
(declare-function calc-recall "calc-store" (&optional var))
diff --git a/lisp/ob-comint.el b/lisp/ob-comint.el
index ba3b99d..c3afd35 100644
--- a/lisp/ob-comint.el
+++ b/lisp/ob-comint.el
@@ -30,7 +30,7 @@
;; org-babel at large.
;;; Code:
-(require 'ob)
+(require 'ob-core)
(require 'org-compat)
(require 'comint)
(eval-when-compile (require 'cl))
diff --git a/lisp/ob-dot.el b/lisp/ob-dot.el
index 99748b0..3ad832b 100644
--- a/lisp/ob-dot.el
+++ b/lisp/ob-dot.el
@@ -39,7 +39,6 @@
;;; Code:
(require 'ob)
-(require 'ob-eval)
(defvar org-babel-default-header-args:dot
'((:results . "file") (:exports . "results"))
diff --git a/lisp/ob-emacs-lisp.el b/lisp/ob-emacs-lisp.el
index 3ba14f6..60e2796 100644
--- a/lisp/ob-emacs-lisp.el
+++ b/lisp/ob-emacs-lisp.el
@@ -27,7 +27,6 @@
;;; Code:
(require 'ob)
-(eval-when-compile (require 'ob-comint))
(defvar org-babel-default-header-args:emacs-lisp
'((:hlines . "yes") (:colnames . "no"))
diff --git a/lisp/ob-exp.el b/lisp/ob-exp.el
index 461421e..e2be94d 100644
--- a/lisp/ob-exp.el
+++ b/lisp/ob-exp.el
@@ -23,7 +23,7 @@
;; along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>.
;;; Code:
-(require 'ob)
+(require 'ob-core)
(eval-when-compile
(require 'cl))
diff --git a/lisp/ob-fortran.el b/lisp/ob-fortran.el
index fb688bc..6faeb79 100644
--- a/lisp/ob-fortran.el
+++ b/lisp/ob-fortran.el
@@ -28,7 +28,6 @@
;;; Code:
(require 'ob)
-(require 'ob-eval)
(require 'cc-mode)
(declare-function org-entry-get "org"
diff --git a/lisp/ob-gnuplot.el b/lisp/ob-gnuplot.el
index 55c4153..7bb705d 100644
--- a/lisp/ob-gnuplot.el
+++ b/lisp/ob-gnuplot.el
@@ -39,8 +39,6 @@
;;; Code:
(require 'ob)
-(require 'ob-ref)
-(require 'ob-comint)
(eval-when-compile (require 'cl))
(declare-function org-time-string-to-time "org" (s))
diff --git a/lisp/ob-haskell.el b/lisp/ob-haskell.el
index 03972ef..358e00f 100644
--- a/lisp/ob-haskell.el
+++ b/lisp/ob-haskell.el
@@ -40,7 +40,6 @@
;;; Code:
(require 'ob)
-(require 'ob-comint)
(require 'comint)
(eval-when-compile (require 'cl))
diff --git a/lisp/ob-io.el b/lisp/ob-io.el
index f47bef8..f4c9add 100644
--- a/lisp/ob-io.el
+++ b/lisp/ob-io.el
@@ -33,9 +33,6 @@
;;; Code:
(require 'ob)
-(require 'ob-ref)
-(require 'ob-comint)
-(require 'ob-eval)
(eval-when-compile (require 'cl))
(defvar org-babel-tangle-lang-exts) ;; Autoloaded
diff --git a/lisp/ob-java.el b/lisp/ob-java.el
index 99f66b9..3b02693 100644
--- a/lisp/ob-java.el
+++ b/lisp/ob-java.el
@@ -28,7 +28,6 @@
;;; Code:
(require 'ob)
-(require 'ob-eval)
(defvar org-babel-tangle-lang-exts)
(add-to-list 'org-babel-tangle-lang-exts '("java" . "java"))
diff --git a/lisp/ob-js.el b/lisp/ob-js.el
index 2138172..31de942 100644
--- a/lisp/ob-js.el
+++ b/lisp/ob-js.el
@@ -39,9 +39,6 @@
;;; Code:
(require 'ob)
-(require 'ob-ref)
-(require 'ob-comint)
-(require 'ob-eval)
(eval-when-compile (require 'cl))
(declare-function run-mozilla "ext:moz" (arg))
diff --git a/lisp/ob-keys.el b/lisp/ob-keys.el
index 3e3f496..283c2b5 100644
--- a/lisp/ob-keys.el
+++ b/lisp/ob-keys.el
@@ -29,7 +29,7 @@
;; functions and their associated keys.
;;; Code:
-(require 'ob)
+(require 'ob-core)
(defvar org-babel-key-prefix "\C-c\C-v"
"The key prefix for Babel interactive key-bindings.
diff --git a/lisp/ob-lilypond.el b/lisp/ob-lilypond.el
index e19b0c3..1a8fa52 100644
--- a/lisp/ob-lilypond.el
+++ b/lisp/ob-lilypond.el
@@ -30,10 +30,7 @@
;; http://lilypond.org/manuals.html
;;; Code:
-
(require 'ob)
-(require 'ob-eval)
-(require 'ob-tangle)
(require 'outline)
(defalias 'lilypond-mode 'LilyPond-mode)
diff --git a/lisp/ob-lob.el b/lisp/ob-lob.el
index 8b5f14d..5c21db7 100644
--- a/lisp/ob-lob.el
+++ b/lisp/ob-lob.el
@@ -25,7 +25,7 @@
;;; Code:
(eval-when-compile
(require 'cl))
-(require 'ob)
+(require 'ob-core)
(require 'ob-table)
(declare-function org-babel-in-example-or-verbatim "ob-exp" nil)
diff --git a/lisp/ob-mscgen.el b/lisp/ob-mscgen.el
index 64d3545..6311f00 100644
--- a/lisp/ob-mscgen.el
+++ b/lisp/ob-mscgen.el
@@ -55,7 +55,6 @@
;;; Code:
(require 'ob)
-(require 'ob-eval)
(defvar org-babel-default-header-args:mscgen
'((:results . "file") (:exports . "results"))
diff --git a/lisp/ob-ocaml.el b/lisp/ob-ocaml.el
index d2bf366..24aa623 100644
--- a/lisp/ob-ocaml.el
+++ b/lisp/ob-ocaml.el
@@ -36,7 +36,6 @@
;;; Code:
(require 'ob)
-(require 'ob-comint)
(require 'comint)
(eval-when-compile (require 'cl))
diff --git a/lisp/ob-octave.el b/lisp/ob-octave.el
index 73f25ec..cd1a44e 100644
--- a/lisp/ob-octave.el
+++ b/lisp/ob-octave.el
@@ -30,9 +30,6 @@
;;; Code:
(require 'ob)
-(require 'ob-ref)
-(require 'ob-comint)
-(require 'ob-eval)
(eval-when-compile (require 'cl))
(declare-function matlab-shell "ext:matlab-mode")
diff --git a/lisp/ob-perl.el b/lisp/ob-perl.el
index abf0ed6..c24e70f 100644
--- a/lisp/ob-perl.el
+++ b/lisp/ob-perl.el
@@ -28,7 +28,6 @@
;;; Code:
(require 'ob)
-(require 'ob-eval)
(eval-when-compile (require 'cl))
(defvar org-babel-tangle-lang-exts)
diff --git a/lisp/ob-picolisp.el b/lisp/ob-picolisp.el
index 1972d29..df577ad 100644
--- a/lisp/ob-picolisp.el
+++ b/lisp/ob-picolisp.el
@@ -54,8 +54,6 @@
;;; Code:
(require 'ob)
-(require 'ob-eval)
-(require 'ob-comint)
(require 'comint)
(eval-when-compile (require 'cl))
diff --git a/lisp/ob-plantuml.el b/lisp/ob-plantuml.el
index 37d8b7d..2313d8e 100644
--- a/lisp/ob-plantuml.el
+++ b/lisp/ob-plantuml.el
@@ -35,7 +35,6 @@
;;; Code:
(require 'ob)
-(require 'ob-eval)
(defvar org-babel-default-header-args:plantuml
'((:results . "file") (:exports . "results"))
diff --git a/lisp/ob-python.el b/lisp/ob-python.el
index e393d1d..d01c6aa 100644
--- a/lisp/ob-python.el
+++ b/lisp/ob-python.el
@@ -28,9 +28,6 @@
;;; Code:
(require 'ob)
-(require 'ob-ref)
-(require 'ob-comint)
-(require 'ob-eval)
(eval-when-compile (require 'cl))
(declare-function org-remove-indentation "org" )
diff --git a/lisp/ob-ref.el b/lisp/ob-ref.el
index af4ee6a..1149111 100644
--- a/lisp/ob-ref.el
+++ b/lisp/ob-ref.el
@@ -49,7 +49,7 @@
;; #+end_src
;;; Code:
-(require 'ob)
+(require 'ob-core)
(eval-when-compile
(require 'cl))
diff --git a/lisp/ob-ruby.el b/lisp/ob-ruby.el
index 54077d0..dc9ad04 100644
--- a/lisp/ob-ruby.el
+++ b/lisp/ob-ruby.el
@@ -37,9 +37,6 @@
;;; Code:
(require 'ob)
-(require 'ob-ref)
-(require 'ob-comint)
-(require 'ob-eval)
(eval-when-compile (require 'cl))
(declare-function run-ruby "ext:inf-ruby" (&optional command name))
diff --git a/lisp/ob-sass.el b/lisp/ob-sass.el
index c960610..5c459d6 100644
--- a/lisp/ob-sass.el
+++ b/lisp/ob-sass.el
@@ -39,7 +39,6 @@
;;; Code:
(require 'ob)
-(require 'ob-eval)
(defvar org-babel-default-header-args:sass '())
diff --git a/lisp/ob-scala.el b/lisp/ob-scala.el
index df344ff..99b18b3 100644
--- a/lisp/ob-scala.el
+++ b/lisp/ob-scala.el
@@ -31,9 +31,6 @@
;;; Code:
(require 'ob)
-(require 'ob-ref)
-(require 'ob-comint)
-(require 'ob-eval)
(eval-when-compile (require 'cl))
(defvar org-babel-tangle-lang-exts) ;; Autoloaded
diff --git a/lisp/ob-scheme.el b/lisp/ob-scheme.el
index ce29928..e6ef755 100644
--- a/lisp/ob-scheme.el
+++ b/lisp/ob-scheme.el
@@ -38,9 +38,6 @@
;;; Code:
(require 'ob)
-(require 'ob-ref)
-(require 'ob-comint)
-(require 'ob-eval)
(eval-when-compile (require 'cl))
(declare-function run-scheme "ext:cmuscheme" (cmd))
diff --git a/lisp/ob-screen.el b/lisp/ob-screen.el
index c628892..f164763 100644
--- a/lisp/ob-screen.el
+++ b/lisp/ob-screen.el
@@ -34,7 +34,6 @@
;;; Code:
(require 'ob)
-(require 'ob-ref)
(defvar org-babel-screen-location "screen"
"The command location for screen.
diff --git a/lisp/ob-sh.el b/lisp/ob-sh.el
index 9b21d05..f918d61 100644
--- a/lisp/ob-sh.el
+++ b/lisp/ob-sh.el
@@ -27,9 +27,6 @@
;;; Code:
(require 'ob)
-(require 'ob-ref)
-(require 'ob-comint)
-(require 'ob-eval)
(require 'shell)
(eval-when-compile (require 'cl))
diff --git a/lisp/ob-sqlite.el b/lisp/ob-sqlite.el
index 1f8a6c0..658ce17 100644
--- a/lisp/ob-sqlite.el
+++ b/lisp/ob-sqlite.el
@@ -27,8 +27,6 @@
;;; Code:
(require 'ob)
-(require 'ob-eval)
-(require 'ob-ref)
(declare-function org-fill-template "org" (template alist))
(declare-function org-table-convert-region "org-table"
diff --git a/lisp/ob-table.el b/lisp/ob-table.el
index 242ddf0..b7cd106 100644
--- a/lisp/ob-table.el
+++ b/lisp/ob-table.el
@@ -50,7 +50,7 @@
;; #+TBLFM: $2='(sbe 'fibbd (n $1))
;;; Code:
-(require 'ob)
+(require 'ob-core)
(defun org-babel-table-truncate-at-newline (string)
"Replace newline character with ellipses.
diff --git a/lisp/ob-tangle.el b/lisp/ob-tangle.el
index 7e25b2c..697a269 100644
--- a/lisp/ob-tangle.el
+++ b/lisp/ob-tangle.el
@@ -26,7 +26,6 @@
;; Extract the code from source blocks out into raw source-code files.
;;; Code:
-(require 'ob)
(require 'org-src)
(eval-when-compile
(require 'cl))
diff --git a/lisp/ob.el b/lisp/ob.el
new file mode 100644
index 0000000..3010503
--- /dev/null
+++ b/lisp/ob.el
@@ -0,0 +1,41 @@
+;;; ob.el --- working with code blocks in org-mode
+
+;; Copyright (C) 2009-2012 Free Software Foundation, Inc.
+
+;; Authors: Eric Schulte
+;; Keywords: literate programming, reproducible research
+;; Homepage: http://orgmode.org
+
+;; This file is part of GNU Emacs.
+
+;; GNU Emacs is free software: you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation, either version 3 of the License, or
+;; (at your option) any later version.
+
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+;; GNU General Public License for more details.
+
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>.
+
+;;; Code:
+(require 'ob-eval)
+(require 'ob-core)
+(require 'ob-comint)
+(require 'ob-exp)
+(require 'ob-keys)
+(require 'ob-table)
+(require 'ob-lob)
+(require 'ob-ref)
+(require 'ob-tangle)
+
+(provide 'ob)
+
+;; Local variables:
+;; generated-autoload-file: "org-loaddefs.el"
+;; End:
+
+;;; ob.el ends here
diff --git a/lisp/org.el b/lisp/org.el
index 3d61f9c..ca26c7b 100644
--- a/lisp/org.el
+++ b/lisp/org.el
@@ -4957,12 +4957,6 @@ This variable is set by `org-before-change-function'.
;; babel
(require 'ob)
-(require 'ob-table)
-(require 'ob-lob)
-(require 'ob-ref)
-(require 'ob-tangle)
-(require 'ob-comint)
-(require 'ob-keys)
;;;###autoload
(define-derived-mode org-mode outline-mode "Org"
diff --git a/lisp/ob-core.el b/lisp/ob-core.el
index 2f4f855..03ac6e1 100644
--- a/lisp/ob-core.el
+++ b/lisp/ob-core.el
@@ -1,4 +1,4 @@
;;; ob.el --- working with code blocks in org-mode
;; Copyright (C) 2009-2012 Free Software Foundation, Inc.
@@ -2622,10 +2622,10 @@ of `org-babel-temporary-directory'."
(add-hook 'kill-emacs-hook 'org-babel-remove-temporary-directory)
-(provide 'ob)
+(provide 'ob-core)
;; Local variables:
;; generated-autoload-file: "org-loaddefs.el"
;; End:
-;;; ob.el ends here
+;;; ob-core.el ends here
@@ -1,4 +1,4 @@
-;;; ob.el --- working with code blocks in org-mode
+;;; ob-core.el --- working with code blocks in org-mode
;; Copyright (C) 2009-2012 Free Software Foundation, Inc.